==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/co/vco102.cpp <==
/*!================================================================
 module:        vco102.cpp
 
 responsible:   ThomasA
 
 special area:  OMS
 
 description:   Oms Tracing   
 
 see:
 
 copyright:     SAP AG 1998 


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/

#include "gco102.h"
#include <string.h>

/*
  Trace Levels
*/

struct CTraceLevel {
  ETraceLevel_co102 m_lvl;
  const char*       m_desc;
};

static CTraceLevel traceLevels_co102[] = {
  omsTrError, "OMS_ERROR",
  omsTrInterface, "OMS_INTERFACE",
  omsTrContainerDir, "OMS_CONTAINERDIR",
  omsTrMemory, "OMS_MEMORY",
  omsTrVarObject, "OMS_VAROBJECT",
  omsTrSession, "OMS_SESSION",
  omsEnumLimit, ""
};
  

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const char* msg) {
  int length = strlen(msg);
  if (m_length + length < m_bufSize) {
    memcpy (m_buffer + m_length, msg, length);
    m_length += length;
  }
  return *this;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const CUnsignedChar_co102& uchar) {
  *this << "x'";
  for (int ix = 0; ix < uchar.length(); ++ix) {
    int  h = uchar[ix];
    char c;
    if ((h >> 8) < 10) {
      c = '0' + (h >> 8);
    }
    else {
      c = 'A' + (h >> 8) - 10;
    }
    this->putChar(c);
    h = h & 0xF;
    if (h < 10) {
      c = '0' + h;
    }
    else {
      c = 'A' + h - 10;
    }
    this->putChar(c);
  }
  *this << "'";
  return *this;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::putInt(tsp00_Longint val) {
  if (val < 0) {
    this->putChar('-');
    val = -val;
  }
  char tmpBuf[22];
  int  digit;
  tmpBuf[21] = 0;
  char* pCurr = &tmpBuf[20];
  while (val > 0) {
    digit = val % m_radix;
    val   /= m_radix;
    if (digit > 9) {
      *pCurr = 'A' + (digit - 10);
    }
    else {
      *pCurr = '0' + digit;
    }
    --pCurr;
  }
  ++pCurr;
  return *this << pCurr;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::putUInt(unsigned long val) {
  char tmpBuf[22];
  int  digit;
  tmpBuf[21] = 0;
  char* pCurr = &tmpBuf[20];
  while (val > 0) {
    digit = val % m_radix;
    val   /= m_radix;
    if (digit > 9) {
      *pCurr = 'A' + (digit - 10);
    }
    else {
      *pCurr = '0' + digit;
    }
    --pCurr;
  }
  ++pCurr;
  return *this << pCurr;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(char c) {
  this->putChar(c);
  return *this;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(double d) {
  char tmpBuf[40];
  sprintf(tmpBuf, "%f", d);
  return *this << tmpBuf;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const void* p)
{
  char tmpBuf[64];
  sprintf(tmpBuf, "%p", p);
  return *this << tmpBuf;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const OmsObjectId& oid) {
  return *this << "OID : " << oid.getPno() << "." << oid.getPos() << "(vers " << oid.getVersion() << ")";
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const GUID& guid) {
  char tmpBuf[64];
  sprintf (tmpBuf, "guid : %8X-%4X-%4X-%1X%1X%1X%1X%1X%1X%1X%1X", guid.Data1, guid.Data2, guid.Data3,
    guid.Data4[0], guid.Data4[1], guid.Data4[2], guid.Data4[3], guid.Data4[4], guid.Data4[5],
    guid.Data4[6], guid.Data4[7]);
  return *this << tmpBuf;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const CFixedLenChar_co102& v) {
  if (m_length + v.length() < m_bufSize) {
    memcpy (m_buffer + m_length, v.str(), v.length());
    m_length += v.length();
  }
  return *this;
}

/*----------------------------------------------------------------------*/

bool CTraceLevel_co102::Set (tsp00_KnlIdentifier& lvl, bool enable) {
  void (CTraceLevel_co102::* pAction)(ETraceLevel_co102);
  pAction = (enable) ? &CTraceLevel_co102::enable : &CTraceLevel_co102::disable;
  int len = sizeof(lvl) - 1;
  while ((len >= 0) && (' ' == lvl[len])) {
    --len;
  }
  ++len;
  char* pLvl = REINTERPRET_CAST(char*, &lvl[0]);
  lvl[len] = 0;
  int idx  = 0;
  do {
    if (0 == strcmp(pLvl, traceLevels_co102[idx].m_desc)) {
      (this->*pAction)(traceLevels_co102[idx].m_lvl);
      return true;
    }
    ++idx;
  }
  while (omsEnumLimit != traceLevels_co102[idx].m_lvl);
  
  return false;
}

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/co/vco102.cpp <==
/*!================================================================
 module:        vco102.cpp
 
 responsible:   ThomasA
 
 special area:  OMS
 
 description:   Oms Tracing   
 
 see:
 
 copyright:     SAP AG 1998 


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

 ===================================================================*/

#include "gco102.h"
#include <string.h>
#include "hsp77.h"     // PTS 1125307

/*
  Trace Levels
*/

struct CTraceLevel {
  ETraceLevel_co102 m_lvl;
  const char*       m_desc;
};

static CTraceLevel traceLevels_co102[] = {
  omsTrError, "OMS_ERROR",
  omsTrInterface, "OMS_INTERFACE",
  omsTrContainerDir, "OMS_CONTAINERDIR",
  omsTrMemory, "OMS_MEMORY",
  omsTrVarObject, "OMS_VAROBJECT",
  omsTrSession, "OMS_SESSION",
  omsTrLock, "OMS_LOCK",
  /* the following are for the detail trace only - in DEBUG mode */
  omsTrContext, "OMS_CONTEXT",
  omsTrNewObj, "OMS_NEWOBJ",
  omsEnumLimit, ""
};
  

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const char* msg) {
  int length = strlen(msg);
  if (m_length + length < m_bufSize) {
    memcpy (m_buffer + m_length, msg, length);
    m_length += length;
  }
  return *this;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const CUnsignedChar_co102& uchar) {
  *this << "x'";
  for (int ix = 0; ix < uchar.length(); ++ix) {
    int  h = uchar[ix];
    char c;
    if ((h >> 8) < 10) {
      c = '0' + (h >> 8);
    }
    else {
      c = 'A' + (h >> 8) - 10;
    }
    this->putChar(c);
    h = h & 0xF;
    if (h < 10) {
      c = '0' + h;
    }
    else {
      c = 'A' + h - 10;
    }
    this->putChar(c);
  }
  *this << "'";
  return *this;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::putInt(tsp00_Longint val) {
  if (val < 0) {
    this->putChar('-');
    val = -val;
  }
  char tmpBuf[22];
  int  digit;
  tmpBuf[21] = 0;
  char* pCurr = &tmpBuf[20];
  while (val > 0) {
    digit = val % m_radix;
    val   /= m_radix;
    if (digit > 9) {
      *pCurr = 'A' + (digit - 10);
    }
    else {
      *pCurr = '0' + digit;
    }
    --pCurr;
  }
  ++pCurr;
  return *this << pCurr;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::putUInt(unsigned long val) {
  char tmpBuf[22];
  int  digit;
  tmpBuf[21] = 0;
  char* pCurr = &tmpBuf[20];
  while (val > 0) {
    digit = val % m_radix;
    val   /= m_radix;
    if (digit > 9) {
      *pCurr = 'A' + (digit - 10);
    }
    else {
      *pCurr = '0' + digit;
    }
    --pCurr;
  }
  ++pCurr;
  return *this << pCurr;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(char c) {
  this->putChar(c);
  return *this;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(double d) {
  char tmpBuf[40];
  //sprintf(tmpBuf, "%f", d);                     // PTS 1125307
  sp77sprintf(tmpBuf, sizeof(tmpBuf), "%f", d);   // PTS 1125307
  return *this << tmpBuf;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const void* p)
{
  char tmpBuf[64];
  //sprintf(tmpBuf, "%p", p);                     // PTS 1125307
  sp77sprintf(tmpBuf, sizeof(tmpBuf), "%p", p);   // PTS 1125307
  return *this << tmpBuf;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const OmsObjectId& oid) {
  return *this << "OID : " << oid.getPno() << "." << oid.getPos() << "(vers " << oid.getVersion() << ")";
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const GUID& guid) {
  char tmpBuf[64];
  //sprintf (tmpBuf, "guid : %8X-%4X-%4X-%1X%1X%1X%1X%1X%1X%1X%1X", guid.Data1, guid.Data2, guid.Data3,
  //  guid.Data4[0], guid.Data4[1], guid.Data4[2], guid.Data4[3], guid.Data4[4], guid.Data4[5],
  //  guid.Data4[6], guid.Data4[7]);                                                                       // PTS 1125307
  sp77sprintf (tmpBuf, sizeof(tmpBuf), "guid : %8X-%4X-%4X-%1X%1X%1X%1X%1X%1X%1X%1X", guid.Data1, guid.Data2, guid.Data3,
    guid.Data4[0], guid.Data4[1], guid.Data4[2], guid.Data4[3], guid.Data4[4], guid.Data4[5],
    guid.Data4[6], guid.Data4[7]);                                                                         // PTS 1125307
  return *this << tmpBuf;
}

/*----------------------------------------------------------------------*/

CTraceStream_co102& CTraceStream_co102::operator<<(const CFixedLenChar_co102& v) {
  if (m_length + v.length() < m_bufSize) {
    memcpy (m_buffer + m_length, v.str(), v.length());
    m_length += v.length();
  }
  return *this;
}

/*----------------------------------------------------------------------*/

bool CTraceLevel_co102::Set (tsp00_KnlIdentifier& lvl, bool enable) {
  void (CTraceLevel_co102::* pAction)(ETraceLevel_co102);
  pAction = (enable) ? &CTraceLevel_co102::enable : &CTraceLevel_co102::disable;
  int len = sizeof(lvl) - 1;
  while ((len >= 0) && (' ' == lvl[len])) {
    --len;
  }
  ++len;
  char* pLvl = REINTERPRET_CAST(char*, &lvl[0]);
  lvl[len] = 0;
  int idx  = 0;
  do {
    if (0 == strcmp(pLvl, traceLevels_co102[idx].m_desc)) {
      (this->*pAction)(traceLevels_co102[idx].m_lvl);
      return true;
    }
    ++idx;
  }
  while (omsEnumLimit != traceLevels_co102[idx].m_lvl);
  
  return false;
}
